==> ocp-common-3.0.0-20200715.040111-78-sources.jar: com/efuture/ocp/common/distributedLock/DistributedLockAspect.java <==
package com.efuture.ocp.common.distributedLock;

import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.efuture.ocp.common.exception.ServiceException;
import com.efuture.ocp.common.language.ResponseCode;
import com.efuture.ocp.common.rest.ServiceLogs;

@Aspect
@Component
public class DistributedLockAspect {

	@Autowired
	DistributedLockHandle lockHandle;

	@Autowired
	DistributedLockKeyHandle keyHandle;

	@Around("@annotation(around)")
	public Object round(ProceedingJoinPoint point, DLock around) throws Throwable {
		ServiceLogs.truedebuglog("DistributedLock", "开始执行", 0);
		String lockKey = "";
		try {
			lockKey = keyHandle.getKey(point, around);
		} catch (Exception e) {
			ServiceLogs.errLog("DistributedLock", e, "获取锁的key失败");
			throw new ServiceException(ResponseCode.EXCEPTION, "获取锁的key失败[{0}]", e.getMessage());
		}
		ServiceLogs.truedebuglog("DistributedLock", "获取到Key:" + lockKey, 0);
		int lockExpire = around.lockExpire();
		boolean locked = false;
		try {
			locked = lockHandle.tryLock(lockKey, lockExpire);
		} catch (Exception e) {
			ServiceLogs.errLog("DistributedLock", e, "获取锁失败[{0}]");
			throw new ServiceException(ResponseCode.EXCEPTION, "获取锁失败[{0}]", lockKey);
		}
		if (!locked) {
			throw new ServiceException(ResponseCode.EXCEPTION, "获取锁失败[{0}]", lockKey);
		}

		Object result = null;
		try {
			result = point.proceed();
		} catch (Throwable e) {
			lockHandle.unlock(lockKey);
			throw e;
		} finally {
			lockHandle.unlock(lockKey);
		}
		return result;

	}
}

==> ocp-common-4.0.0-20201111.080605-12-sources.jar: com/efuture/ocp/common/distributedLock/DistributedLockAspect.java <==
package com.efuture.ocp.common.distributedLock;

import com.efuture.ocp.common.distributedLock.exception.DistributedLockCacheException;
import com.efuture.ocp.common.distributedLock.exception.DistributedLockException;
import com.efuture.ocp.common.distributedLock.exception.DistributedLockGetKeyException;
import com.efuture.ocp.common.distributedLock.exception.DistributedLockIsExistException;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.efuture.ocp.common.language.ResponseCode;
import com.efuture.ocp.common.rest.ServiceLogs;

@Aspect
@Component
public class DistributedLockAspect {

	@Autowired
	DistributedLockHandle lockHandle;

	@Autowired
	DistributedLockKeyHandle keyHandle;

	@Around("@annotation(around)")
	public Object round(ProceedingJoinPoint point, DLock around) throws Throwable {
		ServiceLogs.truedebuglog("DistributedLock", "开始执行", 0);
		String lockKey = "";
		try {
			lockKey = keyHandle.getKey(point, around);
		} catch (Exception e) {
			ServiceLogs.errLog("DistributedLock", e, "获取锁的key失败");
			throw new DistributedLockGetKeyException(ResponseCode.EXCEPTION, "获取锁的key失败[{0}]", e.getMessage());
		}
		ServiceLogs.truedebuglog("DistributedLock", "获取到Key:" + lockKey, 0);
		int lockExpire = around.lockExpire();
		boolean locked = false;
		try {
			locked = lockHandle.tryLock(lockKey, lockExpire, around.waitMillSeconds());
		} catch (Exception e) {
			ServiceLogs.errLog("DistributedLock", e, "获取锁失败[{0}]");
			throw new DistributedLockCacheException(ResponseCode.EXCEPTION, "获取锁失败[{0}]", lockKey);
		}
		if (!locked) {
			throw new DistributedLockIsExistException(ResponseCode.EXCEPTION, "获取锁失败[{0}]", lockKey);
		}

		Object result = null;
		try {
			result = point.proceed();
		} catch (Throwable e) {
			//lockHandle.unlock(lockKey, lockExpire);
			throw e;
		} finally {
			lockHandle.unlock(lockKey, lockExpire);
		}
		return result;

	}
}
